tar_test("torch format", {
  skip_on_cran()
  skip_if_not_installed("torch")
  tar_script({
    list(tar_target(a, torch::torch_tensor(c(1, 2)), format = "torch"))
  })
  tar_make(callr_function = NULL)
  out <- tar_read(a)
  expect_true(inherits(out, "torch_tensor"))
  expect_equal(torch::as_array(out), c(1, 2))
})

tar_test("torch format with in-memory serialization", {
  skip_on_cran()
  skip_if_not_installed("torch")
  future::plan(future::sequential)
  tar_script({
    list(tar_target(a, torch::torch_tensor(c(1, 2)), format = "torch"))
  })
  tar_make_future(callr_function = NULL)
  out <- tar_read(a)
  expect_true(inherits(out, "torch_tensor"))
  expect_equal(torch::as_array(out), c(1, 2))
})

tar_test("torch in-memory serialization of deps", {
  skip_on_cran()
  skip_on_os("windows")
  skip_if_not_installed("clustermq")
  skip_if_not_installed("torch")
  tar_script({
    tar_option_set(packages = "torch", retrieval = "main")
    options(clustermq.scheduler = "multicore")
    list(
      tar_target(tensor, torch_zeros(10), format = "torch"),
      tar_target(array, as.array(tensor))
    )
  })
  capture.output(tar_make_clustermq(reporter = "silent"))
  tar_load(tensor)
  expect_true(inherits(tensor, "torch_tensor"))
  expect_equal(length(tensor), 10)
  tar_load(array)
  expect_equal(array, rep(0, 10))
})

tar_test("validate torch format", {
  skip_if_not_installed("torch")
  x <- target_init(name = "a", expr = quote(f()), format = "torch")
  expect_silent(target_validate(x))
})

tar_test("torch packages", {
  x <- tar_target(x, 1, format = "torch")
  out <- store_get_packages(x$store)
  expect_equal(out, "torch")
})
